# Table des matières

- [Auteur(s)](#auteurs)
- [Travail à réaliser](#travail-à-réaliser)
- [Installation/Tutoriel](#installationtutoriel)
    - [Installation de docker](#installation-de-docker)
    - [Installation de Jenkins](#installation-de-jenkins)
    - [Configuration de base Jenkins et de GitLab](#configuration-de-base-jenkins-et-de-gitlab)
    - [Liaison de Jenkins et de GitLab](#liaison-de-jenkins-et-de-gitlab)
    - [Intégration de Jenkins dans Gitlab](#intégration-de-jenkins-dans-gitlab)
- [Technologies utilisées](#technologies-utilisées)
- [Sources](#sources)

## Auteur(s)

|Nom|Prénom|login|email|
|--|--|--|--|
| *LEFRANCOIS* | *Raphael*| *lr131160* | *raphael.lefrancois@etu.univ-lehavre.fr* |
| *QUESNEY* | *Jules*| *qj141460* | *jules.quesney@etu.univ-lehavre.fr* |
| *VIMBERT* | *Fabien*| *vf130233* | *fabien.vimbert@etu.univ-lehavre.fr* |


## Travail à réaliser

L'objectif de ce mini projet est de se familiariser avec **Docker** à travers un exemple utilisant **Jenkins** et **Git**.


Construisez un conteneur Docker permettant de faire des tests en continu sur une application de votre choix hébergée sur le Git local (de l'université).

Jenkins doit être dans le conteneur et être relié à la Forge de l'université.


*Le rendu* : page(s) web sur votre compte Forge réalisée en Markdown pour présenter votre travail (façon tutoriel). 


*groupe* : par 4 maximum

## Installation/Tutoriel

### Installation de docker

Dans le cas ou docker est déjà installé et que vous souhaitez le supprimer, effectuer la commande :
```shell
sudo apt-get remove docker docker-engine docker.io
```

Dans un premier temps, veuillez mettre à jour les packages présents
```shell
sudo apt-get update
```

Puis installez les packages suivant
```shell
sudo apt-get install \
apt-transport-https \
ca-certificates \
curl \
software-properties-common
```

Enfin, installez docker via la commande suivante
```shell
curl -fsSL https://dowload.docker.com./linux/ubuntu/gpg | sudo apt-key add -
```

Ajoutez ensuite le répertoire suivant
```shell
sudo add-apt-repository "deb [arch-amd64] hattps://dowload.docker.com/linux/ubuntu \
$(lsb_release -cs) 
stable"
```

Enfin, installez docker-ce
```shell
sudo apt-get docker-ce
```

Pour tester si docker fonctionne correctement, vous pouvez effectuer la commande suivante
```shell
sudo run hello-world
```
Si cette dernière commande fonctionne, le terminal devrai vous renvoyer :
```shell
Hello from Docker:
This message shows that your installation appears to be working correctly.
```


### Installation de Jenkins

Dans un premier temps, on cherche une image Ubuntu
```shell
sudo docker search ubuntu
```

Ensuite, on télécharge l'image de Jenkins
```shell
sudo docker pull jenkins
```

Il faut vérifier que le Dockerfile soit présent avant d'effectuer la commande suivante permettant de créer une image de Jenkins
```shell
sudo docker build -t jenkinsinstall .
```

Pour verifier que l'image que l'on vient de créer existe, vous pouvez entrer la commande
```shell
sudo docker images
```


### Configuration de base Jenkins et de GitLab

Pour executer l'image de Jenkins, tapez la commande
```shell
sudo docker run -t -i jenkinsinstall
```

Suite à cette commande, vous aurez le controle d'un termimal à l'intérieur de l'image

A l'intérieur de ce nouveau terminal, tapez :
```shell
service jenkins start
```

Par la suite, vous devrez utiliser votre navigateur favori afin d'avoir accès aux commandes graphique
Pour cela, vous devrez entrer votre IP ainsi qu'un port pour pouvoir avoir accès à l'interface graphique de Jenkins

En tappant cette commande, vous trouverez votre IP à coté de l'interface "eth0"
```shell
ifconfig
```

Par défaut, l'IP est 172.17.0.2 et le port est 8080

Sur votre navigateur, vous devez obtenir le résultat suivant :

![4](img/4_AccessJenkinsFromNav.png)

Sur votre terminal Jenkins, tapez :
```shell
cat /var/lib/jenkins/secrets/initialAdminPassword
```

Copier le résultat puis collez le sur le navigateur

Sur votre navigateur, vous devez obtenir le résultat suivant :

![6](img/6_InstallJenkinsPlug.png)

Selectionnez l'option "installer les plugins suggérés"

Après l'installation, vous devez obtenir le résultat suivant :

![8](img/8_InstallPluginSucess.png)

Cliquez sur "Continuer en tant qu'Administrateur", à noter que votre identifiant sera "admin" et le mot de passe sera le mot de passe de /var/lib/jenkins/secrets/initialAdminPassword

Cliquez sur "Sauver et terminer"

Cliquez sur "Conmmencer à utiliser Jenkins"

Vous devez obtenir le résultat suivant :

![10](img/10_TableauDeBord.png)

Cliquez sur "Nouveau Item"

Cliquez sur "Créer un nouveau job"

Vous devez obtenir le résultat suivant :

![12](img/12_CreateProject.png)

Saisissez un nom et Cliquez sur "Construire un projet free-style" puis sur "OK"





### Liaison de Jenkins et de GitLab

Pour cette partie, nous partons du principe que vous avez accès à un projet que vous possedez.
Dans le cadre de notre tutoriel, nous allons reprendre ce projet (JenkinsGit) avec un fichier HelloWorld.java à tester

Copiez le lien de votre projet : 

![5](img/linkGit.png)

Sur l'interface graphique de jenkins au moment de la configuration d'un projet.
Allez sur "Gestion de code source" et cliquez sur "Git"
Puis collez le lien git sur "Repository URL"

![6](/img/lien2Git.png)

Plus bas dans le formulaire, dans la section "Build", selectionnez l'option "Ajouter un script shell" puis ajoutez vos tests.
Dans notre cas (un simple test de compilation java) le script est

```shell
javac HelloWorld.java
java HelloWorld
```

Puis confirmez le formulaire

Allez ensuite sur Projet > Espace de travail > Lancer un build

### Intégration de Jenkins dans Gitlab

#### Plugin Requis 
    
-   Jenkins GitLab Plugin
-   Jenkins Git Plugin
-   Jenkins GitLab Hook plugin

Premièrement, nous devons créer un utilisateur qui permettras à jenkins d'interagir avec l'API Gitlab.
Cet utilisateur doit avoir les permissions admin sur le projet.
    
Ouvrir Gitlab et aller dans "Setting"
    
![alt text](https://www.swtestacademy.com/wp-content/uploads/2017/01/img_5887647780067.png)

Ensuite, cliquez sur "Access Token" et créez un "token jenkins API"
    
![alt text](https://www.swtestacademy.com/wp-content/uploads/2017/01/img_5887659c22e47-768x382.png)

Sauvegardez et copiez "API token".
    
#### Configurer le serveur Jenkins
    
Allez sur Jenkins et installez "Jenkins Gitlab Plugin" et "Jenkins Git Plugin".
    
Allez dans "Manage Jenkins -> Configure System" et descendre dans la section GitLab.
    
Ecrire l'URL du serveur GitLab et l'ajouter.
    
Puis remplir les champs obligatoires comme sur l'image ci-dessous.

![alt text](https://www.swtestacademy.com/wp-content/uploads/2017/01/img_588767665356d.png)

Selectionez "API Token credential" et cliquez sur test, un message succès devrait s'afficher.

![alt text](https://www.swtestacademy.com/wp-content/uploads/2017/01/img_588737bc65552-1024x268.png)
   
####  Créer et configurer un projet Jenkins 
    
Créez un nouveau projet et cliquez sur configurer.
    
Donnez lui un nom, selectionnez "Discard old builds" et écrire "3" pour “Max # of builds to keep“.
Pour le champs “GitLab connection” selectionnez "predefined connection" qui a été créé avec le plugin GitLab.
Pour Gitlab "Repository Name" ecrire “<group name>/<repository name>“.
    
![alt text](https://www.swtestacademy.com/wp-content/uploads/2017/01/img_58873b96ecb71-1024x267.png)
    
Puis allez dans "Credentials –> System –> “Add domain”" et cliquez sur "Add credentials".
    
![alt text](https://www.swtestacademy.com/wp-content/uploads/2017/01/img_5887400703fc1.png)
    
Puis ajoutez votre id et mots de passe GitLab.
    
Ensuite sélectionnez Git comme "Source Code Management" et remplire les champs comme sur l'image.

![alt text](https://www.swtestacademy.com/wp-content/uploads/2017/01/img_58874682d686d-1024x451.png)
    
####  Build Triggers
Pour la partie build trigers vous pouvez faire comme sur l'image.
    
![alt text](https://www.swtestacademy.com/wp-content/uploads/2017/01/img_5888b78b783a0-800x453.png)
    
Et enfin, ajoutez “Publish build status to GitLab commit” pour accéder à des feedbacks.
    
![alt text](https://www.swtestacademy.com/wp-content/uploads/2017/01/img_5888b85218b82.png)
    
Pour l'integration allez sur votre projet GitLab -> Setting -> intégrations.
Ajoutez votre lien Jenkins.
Vous pouvez maintenant faire un test de connection.

    
Malheureusement l'intégration n'est possible que pour un serveur non Local.
Nous n'avons donc pas pu réaliser cette partie.
    
## Technologies utilisées

- [Docker](https://www.docker.com/)
- [Jenkins](https://jenkins.io/)
- [Gitlab](https://about.gitlab.com/)

## Sources

- https://www.swtestacademy.com/jenkins-gitlab-integration/
- https://jenkins.io/doc/book/installing/